export default {
    "message": "Unexpected token foo",
    "column": 3,
    "index": 24,
    "lineNumber": 2
}